<?php declare(strict_types=1);

namespace massivedynamic\curl;

use CurlHandle;

class Curl {
	private CurlHandle $handle;
	private string     $lastReturn;

	public function __construct(?string $url = null) {
		$this->lastReturn = "";
		$this->handle     = curl_init($url);
	}

	public function errno() : int {
		return curl_errno($this->handle);
	}

	public function error() : Error {
		$errno = $this->errno();
		return new Error(curl_strerror($errno), $errno);
	}

	public function escape(string $string) : ?string {
		$out = curl_escape($this->handle, $string);

		return $out === false ? null : $out;
	}

	public function exec() : bool {
		$result = curl_exec($this->handle);

		if (is_string($result)) {
			$this->lastReturn = $result;
			return true;
		}

		return $result;
	}

	public function getInfo(Info $option) : mixed {
		return curl_getinfo($this->handle, $option->value);
	}

	public function pause(Pause $flag) : int {
		return curl_pause($this->handle, $flag->value);
	}

	public function reset() : void {
		$this->lastReturn = "";
		curl_reset($this->handle);
	}

	public function setOpt(Option $option, mixed $value = null) : bool {
		if (is_array($option)) {
			$options = [];
			array_walk($option, fn($key, $value) => $key instanceof \BackedEnum ? $options[$key->value] = $key : $options[$key] = $value);
			assert($value === null, "Value hast to be null on `setOpt` with an array");
			return curl_setopt_array($this->handle, $options);
		}

		return curl_setopt($this->handle, $option->value, $value === null ? "" : $value);
	}

	public function result() : string {
		return $this->lastReturn;
	}

	public function close() : void {
		curl_close($this->handle);
	}

	public function unescape(string $string) : ?string {
		$out = curl_unescape($this->handle, $string);

		return $out === false ? null : $out;
	}

	public function upkeep() : bool {
		return curl_upkeep($this->handle);
	}

	public function version() : ?array {
		$info = curl_version($this->handle);

		return $info === false ? null : $info;
	}
}